@@ -50,6 +50,7 @@ pub struct Session {
     channels: HashMap<ChannelId, UnboundedSender<OpenChannelMsg>>,
     target_window_size: u32,
     pending_reads: Vec<CryptoVec>,
+    pending_len: u32,
 }
 
 impl Drop for Session {
@@ -809,6 +810,7 @@ where
         sender: sender2,
         channels: HashMap::new(),
         pending_reads: Vec::new(),
+        pending_len: 0,
     };
     session.read_ssh_id(sshid)?;
     let (encrypted_signal, encrypted_recv) = tokio::sync::oneshot::channel();
