@@ -17,8 +17,6 @@ use byteorder::{BigEndian, ByteOrder};
 
 use crate::session::Exchange;
 use cryptovec::CryptoVec;
-#[cfg(feature = "openssl")]
-use openssl;
 use sodium;
 use std::cell::RefCell;
 use thrussh_keys::encoding::Encoding;
