@@ -406,6 +406,9 @@ pub enum Error {
     #[error("Channel send error")]
     SendError,
 
+    #[error("Pending buffer limit reached")]
+    Pending,
+
     #[error(transparent)]
     Keys(#[from] thrussh_keys::Error),
 
