@@ -49,6 +49,7 @@ pub struct Preferred {
 }
 
 impl Preferred {
+    #[cfg(feature = "openssl")]
     pub const DEFAULT: Preferred = Preferred {
         kex: &[kex::CURVE25519],
         key: &[key::ED25519, key::RSA_SHA2_256, key::RSA_SHA2_512],
@@ -57,6 +58,15 @@ impl Preferred {
         compression: &["none", "zlib", "zlib@openssh.com"],
     };
 
+    #[cfg(not(feature = "openssl"))]
+    pub const DEFAULT: Preferred = Preferred {
+        kex: &[kex::CURVE25519],
+        key: &[key::ED25519],
+        cipher: &[cipher::chacha20poly1305::NAME],
+        mac: &["none"],
+        compression: &["none", "zlib", "zlib@openssh.com"],
+    };
+
     pub const COMPRESSED: Preferred = Preferred {
         kex: &[kex::CURVE25519],
         key: &[key::ED25519, key::RSA_SHA2_256, key::RSA_SHA2_512],
