@@ -91,12 +91,17 @@ impl Session {
                     self = self.process_packet(handler, &p).await?
                 }
                 self.pending_reads = pending;
+                self.pending_len = 0;
                 self.common.newkeys(newkeys);
                 self.flush()?;
                 return Ok(self);
             }
             Some(Kex::KexInit(k)) => {
                 enc.rekey = Some(Kex::KexInit(k));
+                self.pending_len += buf.len() as u32;
+                if self.pending_len > 2 * self.target_window_size {
+                    return Err(Error::Pending.into())
+                }
                 self.pending_reads.push(CryptoVec::from_slice(buf));
                 return Ok(self);
             }
